The picture origin (0, 0) is in the top-left corner of its frame with the X and Y axises increasing toward the right and bottom.

To load and save a picture use [LoadPicture], [LoadPNG] or [SavePNG].

The [Picture_SetData] and [Picture_GetData] methods can be used to transfer data to and from a picture object.